---
title: '[공지] 도메인 만료로 인한 결제 장애 (조치 완료)'
category: 공지사항
tags:
  - 공지사항
  - 공통
searchTags:
  - 도메인 만료
  - 오류
datetime: 2024-08-21T07:08:21.703Z
---

안녕하세요. 포트원 고객지원팀입니다.

8월 13일 새벽 시간대에 저희 서비스 도메인(iamport.kr)이 만료되어 IP Resolve가 되지 않는 문제가 발생하였습니다.
대부분의 클라이언트가 IP를 캐싱하고 있었고, 빠른 대처로 전체 장애로 이어지진 않았지만 일부 고객사에서 요청 실패를 경험하게 되었습니다.

해당 장애의 세부 맥락은 다음과 같습니다.

<Indent level="1">

1. 도메인 만료로 장애가 발생한 iamport.kr 은 외부 도메인 등록 대행 서비스에서 관리되는 도메인으로, \
   2024-08-13 에 자동 갱신될 예정이었습니다.
2. 해당 서비스에서 사전에 도메인 자동 갱신 예정 이메일을 발송했으며, 포트원 팀 또한 해당 메일을 통해 갱신에 문제가 없을 것으로 인지하고 있었습니다.
3. 그러나 2024-08-13 갱신예정시점에 도메인 연장 결제가 일어나지 않은 채로 도메인이 만료되었고, 도메인 만료에 대한 알림 또한 받지 못했습니다.
4. 도메인 갱신을 위해 등록된 결제수단에도 문제가 없음을 확인하였고, 도메인을 수동으로 결제 및 갱신함으로써 장애 상황이 종료되었습니다. 이에 대해서는 장애 당일 해당 외부 서비스에 문의 및 클레임을 넣어둔 상황입니다.
5. 포트원 팀에서는 이와 같은 문제를 원천 방지하기 위해 iamport.kr 의 도메인을 타 서비스로 이관하고, 도메인 만료일자 관리 및 모니터링을 통한 수동 갱신 대응 프로세스 또한 준비할 예정입니다.

</Indent>

불편함을 드려 다시 한번 죄송하다는 말씀드립니다.\
앞으로 서비스 안정성을 위해 더욱 더 최선을 다하는 포트원이 되겠습니다.

감사합니다.
